@@ -1,5 +1,5 @@
 """
-Dwarf - Copyright (C) 2019 Giovanni Rocca (iGio90)
+    Dwarf - Copyright (C) 2018-2020 Giovanni Rocca (iGio90)
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -260,20 +260,23 @@ class DeviceBar(QWidget):
             self.updated_frida_version = ''
             self.updated_frida_assets_url.clear()
         else:
-            remote_frida = remote_frida[0]
             self.updated_frida_version = remote_frida['tag_name']
             for asset in remote_frida['assets']:
-                if 'android-' not in asset:
+                if 'name' not in asset:
                     continue
 
-                try:
-                    name = asset['name']
-                    tag_start = name.index('android-')
-                    if name.index('server') >= 0:
-                        tag = name[tag_start + 8:-3]
-                        self.updated_frida_assets_url[tag] = asset['browser_download_url']
-                except ValueError:
-                    pass
+                asset_name = asset['name']
+
+                if not asset_name.startswith('frida-server-'):
+                    continue
+
+                if not 'android' in asset_name:
+                    continue
+
+                tag_start = asset_name.index('android-')
+                if asset_name.index('server') >= 0:
+                    tag = asset_name[tag_start + 8:-3]
+                    self.updated_frida_assets_url[tag] = asset['browser_download_url']
 
     def setup(self):
         """ Setup ui
